Class: Google::Cloud::Domains::V1beta1::OperationMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/domains/v1beta1/domains.rb

Overview

Represents the metadata of the long-running operation. Output only.

Instance Attribute Summary collapse

Instance Attribute Details

#api_version ⇒ ::String

Returns API version used to start the operation.

Returns:

  • (::String) —

    API version used to start the operation.



847
848
849
850
# File 'proto_docs/google/cloud/domains/v1beta1/domains.rb', line 847

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time ⇒ ::Google::Protobuf::Timestamp

Returns The time the operation was created.

Returns:



847
848
849
850
# File 'proto_docs/google/cloud/domains/v1beta1/domains.rb', line 847

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#end_time ⇒ ::Google::Protobuf::Timestamp

Returns The time the operation finished running.

Returns:



847
848
849
850
# File 'proto_docs/google/cloud/domains/v1beta1/domains.rb', line 847

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#status_detail ⇒ ::String

Returns Human-readable status of the operation, if any.

Returns:

  • (::String) —

    Human-readable status of the operation, if any.



847
848
849
850
# File 'proto_docs/google/cloud/domains/v1beta1/domains.rb', line 847

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target ⇒ ::String

Returns Server-defined resource path for the target of the operation.

Returns:

  • (::String) —

    Server-defined resource path for the target of the operation.



847
848
849
850
# File 'proto_docs/google/cloud/domains/v1beta1/domains.rb', line 847

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#verb ⇒ ::String

Returns Name of the verb executed by the operation.

Returns:

  • (::String) —

    Name of the verb executed by the operation.



847
848
849
850
# File 'proto_docs/google/cloud/domains/v1beta1/domains.rb', line 847

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end