Class: Google::Cloud::Domains::V1beta1::TransferParameters

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/domains/v1beta1/domains.rb

Overview

Parameters required to transfer a domain from another registrar.

Instance Attribute Summary collapse

Instance Attribute Details

#current_registrar ⇒ ::String

Returns The registrar that currently manages the domain.

Returns:

  • (::String) —

    The registrar that currently manages the domain.



813
814
815
816
# File 'proto_docs/google/cloud/domains/v1beta1/domains.rb', line 813

class TransferParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#domain_name ⇒ ::String

Returns The domain name. Unicode domain names are expressed in Punycode format.

Returns:

  • (::String) —

    The domain name. Unicode domain names are expressed in Punycode format.



813
814
815
816
# File 'proto_docs/google/cloud/domains/v1beta1/domains.rb', line 813

class TransferParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name_servers ⇒ ::Array<::String>

Returns The name servers that currently store the configuration of the domain.

Returns:

  • (::Array<::String>) —

    The name servers that currently store the configuration of the domain.



813
814
815
816
# File 'proto_docs/google/cloud/domains/v1beta1/domains.rb', line 813

class TransferParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#supported_privacy ⇒ ::Array<::Google::Cloud::Domains::V1beta1::ContactPrivacy>

Returns Contact privacy options that the domain supports.

Returns:



813
814
815
816
# File 'proto_docs/google/cloud/domains/v1beta1/domains.rb', line 813

class TransferParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#transfer_lock_state ⇒ ::Google::Cloud::Domains::V1beta1::TransferLockState

Returns Indicates whether the domain is protected by a transfer lock. For a transfer to succeed, this must show UNLOCKED. To unlock a domain, go to its current registrar.

Returns:



813
814
815
816
# File 'proto_docs/google/cloud/domains/v1beta1/domains.rb', line 813

class TransferParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#yearly_price ⇒ ::Google::Type::Money

Returns Price to transfer or renew the domain for one year.

Returns:



813
814
815
816
# File 'proto_docs/google/cloud/domains/v1beta1/domains.rb', line 813

class TransferParameters
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end